@@ -1,3 +1,3 @@
 from .api import *
 from .core import *
-from .settings import *
+from .models import *
