@@ -20,16 +20,6 @@ def zero_module(module: Module) -> Module:
     return module
 
 
-def conv_nd(n: int, *args: Any, **kwargs: Any) -> Module:
-    if n == 1:
-        return nn.Conv1d(*args, **kwargs)
-    elif n == 2:
-        return nn.Conv2d(*args, **kwargs)
-    elif n == 3:
-        return nn.Conv3d(*args, **kwargs)
-    raise ValueError(f"unsupported dimensions: {n}")
-
-
 def avg_pool_nd(n: int, *args: Any, **kwargs: Any) -> Module:
     if n == 1:
         return nn.AvgPool1d(*args, **kwargs)
@@ -42,7 +32,6 @@ def avg_pool_nd(n: int, *args: Any, **kwargs: Any) -> Module:
 
 __all__ = [
     "Residual",
-    "conv_nd",
     "avg_pool_nd",
     "zero_module",
 ]
